@@ -1,14 +1,15 @@
 class Progressbar:
-    def __init__(self, total, length, prefix, suffix, decimals):
+    def __init__(self, total, length, prefix, suffix, decimals, output_progress):
         self.total = total
         self.length = length
         self.prefix = prefix
         self.suffix = suffix
         self.decimals = decimals
+        self.output_progress = output_progress
 
     def print_progress(self, iteration, action=None):
         progress_bar = self.__build_progress_bar(iteration)
-        if action is not None:
+        if action is not None and self.output_progress:
             print(' ' * len(progress_bar), end='\r')
             print(action)
         print(progress_bar, end='\r')
